import argparse
import cgi
import os.path

from java_visitor import count_components


def parse_args():
    parser = argparse.ArgumentParser(description='Absolute Priority Mass Count.')
    parser.add_argument('filenames', metavar='java_file', nargs='+',
                        help="Java source file you want to count")
    return parser.parse_args()


def print_name(java_source):
    full_file_name = os.path.basename(java_source)
    file_name = os.path.splitext(full_file_name)[0]
    print("<b>{}</b>".format(file_name))


def print_code(java_source):
    with open(java_source) as java_file:
        body = java_file.read().strip()
        html = cgi.escape(body)
        print(('<!--\n\n--><pre class="prettyprint lang-java">' +
              '{}' +
               '</pre><!--\n\n-->').format(html))


def print_table(components):
    table = components.create_table()
    print("<!--\n\n--><pre>\n{}</pre><!--\n\n-->".format(table))


def print_mass(components):
    print("mass: {}".format(str(components.calc_mass())))


if __name__ == '__main__':
    args = parse_args()

    for java_source in args.filenames:
        print_name(java_source)
        print_code(java_source)
        components = count_components(java_source)
        print_table(components)
        print_mass(components)
